"""
VersaLaw2 - Comprehensive Indonesian and International Law Library
Version 2.0 - Improved structure with complete legal modules
"""

from . import core
from . import indonesian_law  
from . import international_law

__all__ = ['core', 'indonesian_law', 'international_law']
__version__ = '2.0.1'
__description__ = "Version 2 - Comprehensive Indonesian Law Library with International Law Modules"
